==> moceansdk-1.1.1.tar.gz: lib/src/modules/message/sms.dart <==
import 'package:moceansdk/src/auth/auth_interface.dart';
import 'package:moceansdk/src/modules/abstract_client.dart';
import 'package:moceansdk/src/modules/transmitter.dart';

class Sms extends AbstractClient {
  Sms(AuthInterface objAuth, Transmitter transmitter)
      : super(objAuth, transmitter);

  set from(String value) {
    this.params['mocean-from'] = value;
  }

  set to(String value) {
    this.params['mocean-to'] = value;
  }

  set text(String value) {
    this.params['mocean-text'] = value;
  }

  set udh(String value) {
    this.params['mocean-udh'] = value;
  }

  set coding(String value) {
    this.params['mocean-coding'] = value;
  }

  set dlrMask(String value) {
    this.params['mocean-dlr-mask'] = value;
  }

  set dlrUrl(String value) {
    this.params['mocean-dlr-url'] = value;
  }

  set schedule(String value) {
    this.params['mocean-schedule'] = value;
  }

  set mClass(String value) {
    this.params['mocean-mclass'] = value;
  }

  set altDcs(String value) {
    this.params['mocean-alt-dcs'] = value;
  }

  set charSet(String value) {
    this.params['mocean-charset'] = value;
  }

  set validity(String value) {
    this.params['mocean-validity'] = value;
  }

  Future send([Map params]) async {
    if (params != null) {
      this.create(params);
    }
    this.isRequiredFieldSet();

    return await this.transmitter.post('/sms', this.params);
  }

  @override
  List requiredKey() {
    var requiredKey = super.requiredKey();
    requiredKey.addAll(['mocean-from', 'mocean-to', 'mocean-text']);
    return requiredKey;
  }
}

==> moceansdk-1.2.0.tar.gz: lib/src/modules/message/sms.dart <==
import 'package:moceansdk/src/auth/auth_interface.dart';
import 'package:moceansdk/src/modules/abstract_client.dart';
import 'package:moceansdk/src/modules/transmitter.dart';

class Sms extends AbstractClient {
  Sms(
    AuthInterface objAuth,
    Transmitter transmitter,
  ) : super(objAuth, transmitter);

  set from(String value) {
    this.params['mocean-from'] = value;
  }

  set to(String value) {
    this.params['mocean-to'] = value;
  }

  set text(String value) {
    this.params['mocean-text'] = value;
  }

  set udh(String value) {
    this.params['mocean-udh'] = value;
  }

  set coding(String value) {
    this.params['mocean-coding'] = value;
  }

  set dlrMask(String value) {
    this.params['mocean-dlr-mask'] = value;
  }

  set dlrUrl(String value) {
    this.params['mocean-dlr-url'] = value;
  }

  set schedule(String value) {
    this.params['mocean-schedule'] = value;
  }

  set mClass(String value) {
    this.params['mocean-mclass'] = value;
  }

  set altDcs(String value) {
    this.params['mocean-alt-dcs'] = value;
  }

  set charSet(String value) {
    this.params['mocean-charset'] = value;
  }

  set validity(String value) {
    this.params['mocean-validity'] = value;
  }

  Future send([Map params]) async {
    if (params != null) {
      this.create(params);
    }
    this.isRequiredFieldSet();

    return await this.transmitter.post('/sms', this.params);
  }

  @override
  List requiredKey() {
    var requiredKey = super.requiredKey();
    requiredKey.addAll(['mocean-from', 'mocean-to', 'mocean-text']);
    return requiredKey;
  }
}
